/* crash.c - demo program for libcrashreport

   (c) 2004 Martin Pitt <martin@piware.de>

   This file is public domain.
*/

#include <stdio.h>

void h(char* p) {
    p[1] = 'a';
}

int g( int x, int y )
{
    char* s = NULL;
    h(s);
    return x+y;
}

int f( int x )
{
    return g( x, 42 );
}

int
main()
{
    int x;

    x = f(1);
    printf( "x = %i, terminating normally now.\n", x );
    return 0;
}
